@@ -78,8 +78,8 @@
                 dataType: 'json',
                 type: 'GET',
                 url: 'auth',
-                data: {
-                    password: getPassword()
+                beforeSend: function (xhr) {
+                    xhr.setRequestHeader('Password', getPassword());
                 },
                 success: function (data) {
                     if (data.auth === 'failed') {
@@ -94,8 +94,8 @@
                 dataType: 'json',
                 type: 'GET',
                 url: 'auth',
-                data: {
-                    password: getPassword()
+                beforeSend: function (xhr) {
+                    xhr.setRequestHeader('Password', getPassword());
                 },
                 success: function (data) {
                     saveCredentials(data, password);
@@ -180,8 +180,8 @@
             $.ajax({
                 dataType: 'json',
                 url: 'maps',
-                data: {
-                    password: getPassword()
+                beforeSend: function (xhr) {
+                    xhr.setRequestHeader('Password', getPassword());
                 },
                 error: function () {
                     alertMessage('alert-modal alert-error', data.statusText);
@@ -191,13 +191,15 @@
                     saveMaps(data);
                     getMapById();
                     $.each(data, function (i, item) {
+                        var caption;
+                        var label;
                         if ((item.editable == false)) {
-                            var caption = 'View';
-                            var label = '<span class="label label-default">Read</span>';
+                            caption = 'View';
+                            label = '<span class="label label-default">Read</span>';
                         }
                         else {
-                            var caption = 'Edit';
-                            var label = '<span class="label label-default">Read</span>&nbsp;<span class="label label-success">Write</span>';
+                            caption = 'Edit';
+                            label = '<span class="label label-default">Read</span>&nbsp;<span class="label label-success">Write</span>';
                         }
                         items.push('<tr>' +
                             '<td class="col-md-2 maps-cell">' + label + '</td>' +
@@ -206,8 +208,11 @@
                             'data-source="#' + item.map + '" ' +
                             'data-editable="' + item.editable + '" ' +
                             'data-target="#modalDialog" ' +
-                            'data-title="' + item.description +
-                            '" data-toggle="modal">' + item.description + '</span>' +
+                            'data-title="' + item.uri +
+                            '" data-toggle="modal">' + item.uri + '</span>' +
+                            '</td>' +
+                            '<td>' +
+                            item.description +
                             '</td>' +
                             '</tr>');
                     });
@@ -369,8 +374,8 @@
                 dataType: 'json',
                 type: 'GET',
                 url: 'pie',
-                data: {
-                    password: getPassword()
+                beforeSend: function (xhr) {
+                    xhr.setRequestHeader('Password', getPassword());
                 },
                 success: function (data) {
                     if (pie) {
@@ -479,8 +484,8 @@
             $.ajax({
                 dataType: 'json',
                 url: 'history',
-                data: {
-                    password: getPassword()
+                beforeSend: function (xhr) {
+                    xhr.setRequestHeader('Password', getPassword());
                 },
                 error: function () {
                     alertMessage('alert-error', 'Cannot receive history');
@@ -544,15 +549,21 @@
                 dataType: 'json',
                 type: 'GET',
                 url: 'symbols',
-                data: {
-                    password: getPassword()
+                beforeSend: function (xhr) {
+                    xhr.setRequestHeader('Password', getPassword());
                 },
                 success: function (data) {
                     $('#modalBody').empty();
+                    data.sort(function(a, b) {
+                        return a.group.localeCompare(b.group);
+                    });
                     $.each(data, function (i, group) {
                         items.push('	<div class="row row-bordered" data-slider="hover">' +
                             '<h4>' + group.group + '</h4>' +
                             '</div>');
+                        group.rules.sort(function(a, b) {
+                            return a.symbol.localeCompare(b.symbol);
+                        });
                         $.each(group.rules, function (i, item) {
                             var max = 20;
                             var min = -20;
@@ -597,8 +608,8 @@
                 dataType: 'json',
                 type: 'GET',
                 url: 'historyreset',
-                data: {
-                    password: getPassword()
+                beforeSend: function (xhr) {
+                    xhr.setRequestHeader('Password', getPassword());
                 },
                 success: function (data) {
                     getHistory();
@@ -896,8 +907,8 @@
                 dataType: 'json',
                 type: 'GET',
                 url: 'actions',
-                data: {
-                    password: getPassword()
+                beforeSend: function (xhr) {
+                    xhr.setRequestHeader('Password', getPassword());
                 },
                 success: function (data) {
                     // Order of sliders greylist -> probable spam -> spam
@@ -1070,8 +1081,8 @@
                     dataType: 'json',
                     type: 'GET',
                     url: 'auth',
-                    data: {
-                        password: password
+                    beforeSend: function (xhr) {
+                        xhr.setRequestHeader('Password', password);
                     },
                     success: function (data) {
                         if (data.auth === 'failed') {
